@@ -38,8 +38,6 @@
  *
  * For example, when the inferior creates a new thread, the debugger
  * implementation should call ide_debugger_emit_thread_added().
- *
- * Since: 3.32
  */
 
 typedef struct
@@ -499,8 +497,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * The "display-name" property is used by UI to when it is necessary
    * to display the name of the debugger. You might set this to "GNU Debugger"
    * or "Python Debugger", etc.
-   *
-   * Since: 3.32
    */
   properties [PROP_DISPLAY_NAME] =
     g_param_spec_string ("display-name",
@@ -513,8 +509,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * IdeDebugger:selected-thread:
    *
    * The currently selected thread.
-   *
-   * Since: 3.32
    */
   properties [PROP_SELECTED_THREAD] =
     g_param_spec_object ("selected-thread",
@@ -533,8 +527,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    *
    * The "log" signal is emitted when there is new content to be
    * appended to one of the streams.
-   *
-   * Since: 3.32
    */
   signals [LOG] =
     g_signal_new ("log",
@@ -553,8 +545,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * @thread_group: an #IdeDebuggerThreadGroup
    *
    * This signal is emitted when a thread-group has been added.
-   *
-   * Since: 3.32
    */
   signals [THREAD_GROUP_ADDED] =
     g_signal_new ("thread-group-added",
@@ -572,8 +562,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * @thread_group: an #IdeDebuggerThreadGroup
    *
    * This signal is emitted when a thread-group has been removed.
-   *
-   * Since: 3.32
    */
   signals [THREAD_GROUP_REMOVED] =
     g_signal_new ("thread-group-removed",
@@ -591,8 +579,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * @thread_group: an #IdeDebuggerThreadGroup
    *
    * This signal is emitted when a thread-group has been started.
-   *
-   * Since: 3.32
    */
   signals [THREAD_GROUP_STARTED] =
     g_signal_new ("thread-group-started",
@@ -610,8 +596,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * @thread_group: an #IdeDebuggerThreadGroup
    *
    * This signal is emitted when a thread-group has exited.
-   *
-   * Since: 3.32
    */
   signals [THREAD_GROUP_EXITED] =
     g_signal_new ("thread-group-exited",
@@ -627,8 +611,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * @thread: an #IdeDebuggerThread
    *
    * The signal is emitted when a thread is added to the inferior.
-   *
-   * Since: 3.32
    */
   signals [THREAD_ADDED] =
     g_signal_new ("thread-added",
@@ -644,8 +626,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * @thread: an #IdeDebuggerThread
    *
    * The signal is emitted when a thread is removed from the inferior.
-   *
-   * Since: 3.32
    */
   signals [THREAD_REMOVED] =
     g_signal_new ("thread-removed",
@@ -661,8 +641,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * @thread: an #IdeDebuggerThread
    *
    * The signal is emitted when a thread is selected in the debugger.
-   *
-   * Since: 3.32
    */
   signals [THREAD_SELECTED] =
     g_signal_new ("thread-selected",
@@ -679,8 +657,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    *
    * The "breakpoint-added" signal is emitted when a breakpoint has been
    * added to the debugger.
-   *
-   * Since: 3.32
    */
   signals [BREAKPOINT_ADDED] =
     g_signal_new ("breakpoint-added",
@@ -697,8 +673,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    *
    * The "breakpoint-removed" signal is emitted when a breakpoint has been
    * removed from the debugger.
-   *
-   * Since: 3.32
    */
   signals [BREAKPOINT_REMOVED] =
     g_signal_new ("breakpoint-removed",
@@ -715,8 +689,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    *
    * The "breakpoint-modified" signal is emitted when a breakpoint has been
    * modified by the debugger.
-   *
-   * Since: 3.32
    */
   signals [BREAKPOINT_MODIFIED] =
     g_signal_new ("breakpoint-modified",
@@ -732,8 +704,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    *
    * This signal is emitted when the debugger starts or resumes executing
    * the inferior.
-   *
-   * Since: 3.32
    */
   signals [RUNNING] =
     g_signal_new ("running",
@@ -755,8 +725,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * the location the debugger stopped. That location may not always be
    * representable by source in the project (such as memory address based
    * breakpoints).
-   *
-   * Since: 3.32
    */
   signals [STOPPED] =
     g_signal_new ("stopped",
@@ -775,8 +743,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * @library: An #IdeDebuggerLibrary
    *
    * This signal is emitted when a library has been loaded by the debugger.
-   *
-   * Since: 3.32
    */
   signals [LIBRARY_LOADED] =
     g_signal_new ("library-loaded",
@@ -794,8 +760,6 @@ ide_debugger_class_init (IdeDebuggerClass *klass)
    * This signal is emitted when a library has been unloaded by the debugger.
    * Generally, this means that the library was a module and loaded in such a
    * way that allowed unloading.
-   *
-   * Since: 3.32
    */
   signals [LIBRARY_UNLOADED] =
     g_signal_new ("library-unloaded",
@@ -825,8 +789,6 @@ ide_debugger_init (IdeDebugger *self)
  * UI components.
  *
  * Returns: The display name for the debugger
- *
- * Since: 3.32
  */
 const gchar *
 ide_debugger_get_display_name (IdeDebugger *self)
@@ -843,8 +805,6 @@ ide_debugger_get_display_name (IdeDebugger *self)
  * @self: a #IdeDebugger
  *
  * Sets the #IdeDebugger:display-name property.
- *
- * Since: 3.32
  */
 void
 ide_debugger_set_display_name (IdeDebugger *self,
@@ -870,8 +830,6 @@ ide_debugger_set_display_name (IdeDebugger *self,
  * Checks to see if the debugger can make the movement matching @movement.
  *
  * Returns: %TRUE if @movement can be performed.
- *
- * Since: 3.32
  */
 gboolean
 ide_debugger_get_can_move (IdeDebugger         *self,
@@ -896,8 +854,6 @@ ide_debugger_get_can_move (IdeDebugger         *self,
  *
  * Advances the debugger to the next breakpoint or until the debugger stops.
  * @movement should describe the type of movement to perform.
- *
- * Since: 3.32
  */
 void
 ide_debugger_move_async (IdeDebugger         *self,
@@ -925,8 +881,6 @@ ide_debugger_move_async (IdeDebugger         *self,
  * only that the command has be submitted.
  *
  * Returns: %TRUE if successful, otherwise %FALSE
- *
- * Since: 3.32
  */
 gboolean
 ide_debugger_move_finish (IdeDebugger   *self,
@@ -949,8 +903,6 @@ ide_debugger_move_finish (IdeDebugger   *self,
  * that incoming log information has been recieved.
  *
  * Use the #IdeDebuggerStream to denote the particular stream.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_log (IdeDebugger       *self,
@@ -971,8 +923,6 @@ ide_debugger_emit_log (IdeDebugger       *self,
  *
  * Debugger implementations should call this to notify that a thread group has
  * been added to the inferior.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_thread_group_added (IdeDebugger            *self,
@@ -991,8 +941,6 @@ ide_debugger_emit_thread_group_added (IdeDebugger            *self,
  *
  * Debugger implementations should call this to notify that a thread group has
  * been removed from the inferior.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_thread_group_removed (IdeDebugger            *self,
@@ -1011,8 +959,6 @@ ide_debugger_emit_thread_group_removed (IdeDebugger            *self,
  *
  * Debugger implementations should call this to notify that a thread group has
  * started executing.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_thread_group_started (IdeDebugger            *self,
@@ -1031,8 +977,6 @@ ide_debugger_emit_thread_group_started (IdeDebugger            *self,
  *
  * Debugger implementations should call this to notify that a thread group has
  * exited.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_thread_group_exited (IdeDebugger            *self,
@@ -1051,8 +995,6 @@ ide_debugger_emit_thread_group_exited (IdeDebugger            *self,
  *
  * Emits the #IdeDebugger::thread-added signal notifying that a new thread
  * has been added to the inferior.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_thread_added (IdeDebugger       *self,
@@ -1071,8 +1013,6 @@ ide_debugger_emit_thread_added (IdeDebugger       *self,
  *
  * Emits the #IdeDebugger::thread-removed signal notifying that a thread has
  * been removed to the inferior.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_thread_removed (IdeDebugger       *self,
@@ -1091,8 +1031,6 @@ ide_debugger_emit_thread_removed (IdeDebugger       *self,
  *
  * Emits the #IdeDebugger::thread-selected signal notifying that a thread
  * has been set as the current debugging thread.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_thread_selected (IdeDebugger       *self,
@@ -1116,8 +1054,6 @@ ide_debugger_emit_thread_selected (IdeDebugger       *self,
  *
  * If a breakpoint has changed, you should use
  * ide_debugger_emit_breakpoint_modified() to notify of the modification.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_breakpoint_added (IdeDebugger           *self,
@@ -1141,8 +1077,6 @@ ide_debugger_emit_breakpoint_added (IdeDebugger           *self,
  *
  * If a breakpoint has changed, you should use
  * ide_debugger_emit_breakpoint_modified() to notify of the modification.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_breakpoint_removed (IdeDebugger           *self,
@@ -1163,8 +1097,6 @@ ide_debugger_emit_breakpoint_removed (IdeDebugger           *self,
  *
  * Debugger implementations should call this when a breakpoint has changed
  * in the underlying debugger.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_breakpoint_modified (IdeDebugger           *self,
@@ -1184,8 +1116,6 @@ ide_debugger_emit_breakpoint_modified (IdeDebugger           *self,
  *
  * Debugger implementations should call this when the debugger has started
  * or restarted executing the inferior.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_running (IdeDebugger *self)
@@ -1205,8 +1135,6 @@ ide_debugger_emit_running (IdeDebugger *self)
  *
  * Debugger implementations should call this when the debugger has stopped
  * and include the reason and location of the stop.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_stopped (IdeDebugger           *self,
@@ -1229,8 +1157,6 @@ ide_debugger_emit_stopped (IdeDebugger           *self,
  *
  * Debugger implementations should call this when the debugger has loaded
  * a new library.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_library_loaded (IdeDebugger        *self,
@@ -1251,8 +1177,6 @@ ide_debugger_emit_library_loaded (IdeDebugger        *self,
  *
  * Debugger implementations should call this when the debugger has unloaded a
  * library.
- *
- * Since: 3.32
  */
 void
 ide_debugger_emit_library_unloaded (IdeDebugger        *self,
@@ -1275,8 +1199,6 @@ ide_debugger_emit_library_unloaded (IdeDebugger        *self,
  *
  * #IdeDebugger implementations must implement the virtual function
  * for this method.
- *
- * Since: 3.32
  */
 void
 ide_debugger_list_breakpoints_async (IdeDebugger         *self,
@@ -1300,8 +1222,6 @@ ide_debugger_list_breakpoints_async (IdeDebugger         *self,
  *
  * Returns: (transfer full) (element-type Ide.DebuggerBreakpoint): a #GPtrArray
  *   of breakpoints that are registered with the debugger.
- *
- * Since: 3.32
  */
 GPtrArray *
 ide_debugger_list_breakpoints_finish (IdeDebugger   *self,
@@ -1327,8 +1247,6 @@ ide_debugger_list_breakpoints_finish (IdeDebugger   *self,
  * This asynchronous function may complete before the breakpoint has been
  * registered in the debugger. Debugger implementations will emit
  * #IdeDebugger::breakpoint-added when a breakpoint has been registered.
- *
- * Since: 3.32
  */
 void
 ide_debugger_insert_breakpoint_async (IdeDebugger             *self,
@@ -1360,8 +1278,6 @@ ide_debugger_insert_breakpoint_async (IdeDebugger             *self,
  *
  * Returns: %TRUE if the command was submitted successfully; otherwise %FALSE
  *   and @error is set.
- *
- * Since: 3.32
  */
 gboolean
 ide_debugger_insert_breakpoint_finish (IdeDebugger   *self,
@@ -1387,8 +1303,6 @@ ide_debugger_insert_breakpoint_finish (IdeDebugger   *self,
  * This asynchronous function may complete before the breakpoint has been
  * removed by the debugger. Debugger implementations will emit
  * #IdeDebugger::breakpoint-removed when a breakpoint has been removed.
- *
- * Since: 3.32
  */
 void
 ide_debugger_remove_breakpoint_async (IdeDebugger             *self,
@@ -1419,8 +1333,6 @@ ide_debugger_remove_breakpoint_async (IdeDebugger             *self,
  * See also: ide_debugger_remove_breakpoint_async()
  *
  * Returns: %TRUE if the command was submitted successfully; otherwise %FALSE and @error is set.
- *
- * Since: 3.32
  */
 gboolean
 ide_debugger_remove_breakpoint_finish (IdeDebugger   *self,
@@ -1449,8 +1361,6 @@ ide_debugger_remove_breakpoint_finish (IdeDebugger   *self,
  * This asynchronous function may complete before the breakpoint has been
  * modified by the debugger. Debugger implementations will emit
  * #IdeDebugger::breakpoint-modified when a breakpoint has been removed.
- *
- * Since: 3.32
  */
 void
 ide_debugger_modify_breakpoint_async (IdeDebugger                 *self,
@@ -1486,8 +1396,6 @@ ide_debugger_modify_breakpoint_async (IdeDebugger                 *self,
  * #IdeDebugger::breakpoint-modified signal.
  *
  * Returns: %TRUE if successful; otherwise %FALSE and @error is set.
- *
- * Since: 3.32
  */
 gboolean
 ide_debugger_modify_breakpoint_finish (IdeDebugger   *self,
@@ -1515,8 +1423,6 @@ ide_debugger_modify_breakpoint_finish (IdeDebugger   *self,
  * display information on breakpoints.
  *
  * Returns: (transfer none) (not nullable): a #GListModel of #IdeDebuggerBreakpoint
- *
- * Since: 3.32
  */
 GListModel *
 ide_debugger_get_breakpoints (IdeDebugger *self)
@@ -1538,8 +1444,6 @@ ide_debugger_get_breakpoints (IdeDebugger *self)
  * implementation emitting varous thread-group modification signals correctly.
  *
  * Returns: (transfer none) (not nullable): a #GListModel of #IdeDebuggerThreadGroup
- *
- * Since: 3.32
  */
 GListModel *
 ide_debugger_get_thread_groups (IdeDebugger *self)
@@ -1561,8 +1465,6 @@ ide_debugger_get_thread_groups (IdeDebugger *self)
  * implementation emitting varous thread modification signals correctly.
  *
  * Returns: (transfer none) (not nullable): a #GListModel of #IdeDebuggerThread
- *
- * Since: 3.32
  */
 GListModel *
 ide_debugger_get_threads (IdeDebugger *self)
@@ -1595,8 +1497,6 @@ ide_debugger_list_frames_async (IdeDebugger         *self,
  *
  * Returns: (transfer full) (element-type Ide.DebuggerFrame) (nullable): An
  *   array of debugger frames or %NULL and @error is set.
- *
- * Since: 3.32
  */
 GPtrArray *
 ide_debugger_list_frames_finish (IdeDebugger   *self,
@@ -1616,8 +1516,6 @@ ide_debugger_list_frames_finish (IdeDebugger   *self,
  * Gets the current selected thread by the debugger.
  *
  * Returns: (transfer none) (nullable): An #IdeDebuggerThread or %NULL
- *
- * Since: 3.32
  */
 IdeDebuggerThread *
 ide_debugger_get_selected_thread (IdeDebugger *self)
@@ -1641,8 +1539,6 @@ ide_debugger_get_selected_thread (IdeDebugger *self)
  * group. Thread groups are a collection of threads that are executed or
  * stopped together and on gdb on Linux, this is the default for all threads in
  * the process.
- *
- * Since: 3.32
  */
 void
 ide_debugger_interrupt_async (IdeDebugger            *self,
@@ -1729,8 +1625,6 @@ ide_debugger_send_signal_finish (IdeDebugger   *self,
  * but that may change based on future design changes.
  *
  * Returns: the filename of the binary or %NULL
- *
- * Since: 3.32
  */
 const gchar *
 ide_debugger_locate_binary_at_address (IdeDebugger        *self,
@@ -1760,8 +1654,6 @@ ide_debugger_locate_binary_at_address (IdeDebugger        *self,
  *
  * Requests the debugger backend to list the locals that are available to the
  * given @frame of @thread.
- *
- * Since: 3.32
  */
 void
 ide_debugger_list_locals_async (IdeDebugger         *self,
@@ -1794,8 +1686,6 @@ ide_debugger_list_locals_async (IdeDebugger         *self,
  *
  * Returns: (transfer full) (element-type Ide.DebuggerVariable): a #GPtrArray of
  *   #IdeDebuggerVariable if successful; otherwise %NULL and error is set.
- *
- * Since: 3.32
  */
 GPtrArray *
 ide_debugger_list_locals_finish (IdeDebugger   *self,
@@ -1819,8 +1709,6 @@ ide_debugger_list_locals_finish (IdeDebugger   *self,
  *
  * Requests the debugger backend to list the parameters to the given stack
  * frame.
- *
- * Since: 3.32
  */
 void
 ide_debugger_list_params_async (IdeDebugger         *self,
@@ -1853,8 +1741,6 @@ ide_debugger_list_params_async (IdeDebugger         *self,
  *
  * Returns: (transfer full) (element-type Ide.DebuggerVariable): a #GPtrArray of
  *   #IdeDebuggerVariable if successful; otherwise %NULL and error is set.
- *
- * Since: 3.32
  */
 GPtrArray *
 ide_debugger_list_params_finish (IdeDebugger   *self,
@@ -1875,8 +1761,6 @@ ide_debugger_list_params_finish (IdeDebugger   *self,
  * @user_data: user data for @callback
  *
  * Requests the list of registers and their values.
- *
- * Since: 3.32
  */
 void
 ide_debugger_list_registers_async (IdeDebugger         *self,
@@ -1900,8 +1784,6 @@ ide_debugger_list_registers_async (IdeDebugger         *self,
  *
  * Returns: (transfer full) (element-type Ide.DebuggerRegister): a #GPtrArray of
  *   #IdeDebuggerRegister if successful; otherwise %NULL and error is set.
- *
- * Since: 3.32
  */
 GPtrArray *
 ide_debugger_list_registers_finish (IdeDebugger   *self,
@@ -1923,8 +1805,6 @@ ide_debugger_list_registers_finish (IdeDebugger   *self,
  * @user_data: user data for @callback
  *
  * Disassembles the address range requested.
- *
- * Since: 3.32
  */
 void
 ide_debugger_disassemble_async (IdeDebugger                   *self,
@@ -1950,8 +1830,6 @@ ide_debugger_disassemble_async (IdeDebugger                   *self,
  *
  * Returns: (transfer full) (element-type Ide.DebuggerInstruction): a #GPtrArray
  *   of #IdeDebuggerInstruction if successful; otherwise %NULL and error is set.
- *
- * Since: 3.32
  */
 GPtrArray *
 ide_debugger_disassemble_finish (IdeDebugger   *self,
@@ -1967,52 +1845,54 @@ ide_debugger_disassemble_finish (IdeDebugger   *self,
 /**
  * ide_debugger_supports_runner:
  * @self: an #IdeDebugger
- * @runner: an #IdeRunner
+ * @pipeline: an #IdePipeline
+ * #run_command: an #IdeRunCommand
  * @priority: (out): A location for a priority
  *
  * Checks if the debugger supports a given runner. The debugger may need
  * to check if the binary type matches it's expectation.
  *
  * Returns: %TRUE if the #IdeDebugger supports the runner.
- *
- * Since: 3.32
  */
 gboolean
-ide_debugger_supports_runner (IdeDebugger *self,
-                              IdeRunner   *runner,
-                              gint        *priority)
+ide_debugger_supports_run_command (IdeDebugger   *self,
+                                   IdePipeline   *pipeline,
+                                   IdeRunCommand *run_command,
+                                   int           *priority)
 {
-  gint dummy = 0;
+  int dummy = 0;
 
   g_return_val_if_fail (IDE_IS_DEBUGGER (self), FALSE);
-  g_return_val_if_fail (IDE_IS_RUNNER (runner), FALSE);
+  g_return_val_if_fail (IDE_IS_PIPELINE (pipeline), FALSE);
+  g_return_val_if_fail (IDE_IS_RUN_COMMAND (run_command), FALSE);
 
   if (priority == NULL)
     priority = &dummy;
   else
     *priority = 0;
 
-  return IDE_DEBUGGER_GET_CLASS (self)->supports_runner (self, runner, priority);
+  return IDE_DEBUGGER_GET_CLASS (self)->supports_run_command (self, pipeline, run_command, priority);
 }
 
 /**
- * ide_debugger_prepare:
+ * ide_debugger_prepare_for_run:
  * @self: an #IdeDebugger
- * @runner: an #IdeRunner
+ * @pipeline: an #IdePipeline
+ * @run_context: an #IdeRunContext
  *
  * Prepares the runner to launch a debugger and target process.
- *
- * Since: 3.32
  */
 void
-ide_debugger_prepare (IdeDebugger *self,
-                      IdeRunner   *runner)
+ide_debugger_prepare_for_run (IdeDebugger   *self,
+                              IdePipeline   *pipeline,
+                              IdeRunContext *run_context)
 {
   g_return_if_fail (IDE_IS_DEBUGGER (self));
-  g_return_if_fail (IDE_IS_RUNNER (runner));
+  g_return_if_fail (IDE_IS_PIPELINE (pipeline));
+  g_return_if_fail (IDE_IS_RUN_CONTEXT (run_context));
+  g_return_if_fail (IDE_DEBUGGER_GET_CLASS (self)->prepare_for_run != NULL);
 
-  if (IDE_DEBUGGER_GET_CLASS (self)->prepare)
-    IDE_DEBUGGER_GET_CLASS (self)->prepare (self, runner);
+  IDE_DEBUGGER_GET_CLASS (self)->prepare_for_run (self, pipeline, run_context);
 }
 
 /**
@@ -2033,8 +1913,6 @@ ide_debugger_prepare (IdeDebugger *self,
  *
  * Call ide_debugger_interpret_finish() from @callback to determine if the
  * command was interpreted.
- *
- * Since: 3.32
  */
 void
 ide_debugger_interpret_async (IdeDebugger         *self,
@@ -2060,8 +1938,6 @@ ide_debugger_interpret_async (IdeDebugger         *self,
  *
  * Returns: %TRUE if the command was interpreted, otherwise %FALSE and
  *    @error is set.
- *
- * Since: 3.32
  */
 gboolean
 ide_debugger_interpret_finish (IdeDebugger   *self,
