@@ -1049,6 +1049,35 @@ on_scroll_scrolled_cb (GtkEventControllerScroll *scroll,
   return FALSE;
 }
 
+static void
+on_scroll_begin_cb (GtkEventControllerScroll *scroll,
+                    IdeSourceView            *self)
+{
+  GdkModifierType state;
+
+  g_assert (IDE_IS_MAIN_THREAD ());
+  g_assert (GTK_IS_EVENT_CONTROLLER_SCROLL (scroll));
+  g_assert (IDE_IS_SOURCE_VIEW (self));
+
+  state = gtk_event_controller_get_current_event_state (GTK_EVENT_CONTROLLER (scroll));
+
+  if (state & GDK_CONTROL_MASK)
+    gtk_event_controller_scroll_set_flags (scroll,
+                                           GTK_EVENT_CONTROLLER_SCROLL_VERTICAL |
+                                           GTK_EVENT_CONTROLLER_SCROLL_DISCRETE);
+}
+
+static void
+on_scroll_end_cb (GtkEventControllerScroll *scroll,
+                  IdeSourceView            *self)
+{
+  g_assert (IDE_IS_MAIN_THREAD ());
+  g_assert (GTK_IS_EVENT_CONTROLLER_SCROLL (scroll));
+  g_assert (IDE_IS_SOURCE_VIEW (self));
+
+  gtk_event_controller_scroll_set_flags (scroll, GTK_EVENT_CONTROLLER_SCROLL_VERTICAL);
+}
+
 static void
 ide_source_view_push_snippet (GtkSourceView    *source_view,
                               GtkSourceSnippet *snippet,
@@ -1428,7 +1457,10 @@ ide_source_view_class_init (IdeSourceViewClass *klass)
   gtk_widget_class_install_action (widget_class, "buffer.duplicate-line", NULL, ide_source_view_action_duplicate_line);
 
   gtk_widget_class_add_binding_action (widget_class, GDK_KEY_plus, GDK_CONTROL_MASK, "zoom.in", NULL);
+  gtk_widget_class_add_binding_action (widget_class, GDK_KEY_KP_Add, GDK_CONTROL_MASK, "zoom.in", NULL);
+  gtk_widget_class_add_binding_action (widget_class, GDK_KEY_equal, GDK_CONTROL_MASK, "zoom.in", NULL);
   gtk_widget_class_add_binding_action (widget_class, GDK_KEY_minus, GDK_CONTROL_MASK, "zoom.out", NULL);
+  gtk_widget_class_add_binding_action (widget_class, GDK_KEY_KP_Subtract, GDK_CONTROL_MASK, "zoom.out", NULL);
   gtk_widget_class_add_binding_action (widget_class, GDK_KEY_0, GDK_CONTROL_MASK, "zoom.one", NULL);
   gtk_widget_class_add_binding_action (widget_class, GDK_KEY_l, GDK_CONTROL_MASK, "buffer.select-line", NULL);
   gtk_widget_class_add_binding_action (widget_class, GDK_KEY_d, GDK_CONTROL_MASK, "buffer.delete-line", NULL);
@@ -1506,6 +1538,14 @@ ide_source_view_init (IdeSourceView *self)
                     "scroll",
                     G_CALLBACK (on_scroll_scrolled_cb),
                     self);
+  g_signal_connect (scroll,
+                    "scroll-begin",
+                    G_CALLBACK (on_scroll_begin_cb),
+                    self);
+  g_signal_connect (scroll,
+                    "scroll-end",
+                    G_CALLBACK (on_scroll_end_cb),
+                    self);
   ide_source_view_add_controller (self, 0, scroll);
 
   /* This is sort of a layer vioaltion, but it's helpful for us to
